@@ -1,11 +1,13 @@
 /* GENIUS Calculator
- * Copyright (C) 1997-2005 Jiri (George) Lebl
+ * Copyright (C) 1997-2007 Jiri (George) Lebl
  *
  * Author: Jiri (George) Lebl
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of Genius.
+ *
+ * Genius is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,9 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the  Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
- * USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef CALC_H_
@@ -29,7 +29,7 @@
 
 #include "structs.h"
 
-#define COPYRIGHT_STRING "Copyright (C) 1997-2006 Jiri (George) Lebl"
+#define COPYRIGHT_STRING "Copyright (C) 1997-2007 Jiří (George) Lebl, Ph.D."
 
 typedef enum {
 	NO_ERROR = 0,
@@ -65,6 +65,11 @@ typedef struct _calcstate_t {
 	gboolean mixed_fractions; /*if we should print fractions in mixed format*/
 	int integer_output_base; /*output base for integers*/
 	GelOutputStyle output_style;
+	int max_nodes;	/*maximum number of nodes +- whatever*/
+	int chop;	/* chop floating point numbers 
+			   smaller than approximately 10^-chop */
+	int chop_when;  /* but only if the object contains a number greater
+			   than 10^-chop_when */
 } calcstate_t;
 
 /*so we can use and set the yyparse function for parse errors*/
